diff --git a/debian/cdrom-detect.postinst b/debian/cdrom-detect.postinst
index 3446a06..6bf2454 100755
--- a/debian/cdrom-detect.postinst
+++ b/debian/cdrom-detect.postinst
@@ -223,6 +223,22 @@ while true; do
 	fi
 done
 
+# Check for unetbootin files
+UNETBOOTIN_FILES="ubnfilel.txt ubninit ubnkern ubnpathl.txt"
+UNETBOOTIN_DETECTED=0
+for file in ${UNETBOOTIN_FILES}; do
+	if [ -f /cdrom/$file ] ; then
+		UNETBOOTIN_DETECTED=1
+		break
+	fi
+done
+
+# If we found any, warn the user
+if [ $UNETBOOTIN_DETECTED = 1 ]; then
+	db_input critical cdrom-detect/unetbootin_detected || [ $? -eq 30 ]
+	db_go
+fi
+
 # Get all the pool directories into the dentry cache, to cut down on seek
 # times.
 poolcount="$(set -- /cdrom/pool/*/*; echo $#)"
diff --git a/debian/cdrom-detect.templates b/debian/cdrom-detect.templates
index 3db18bc..96253af 100644
--- a/debian/cdrom-detect.templates
+++ b/debian/cdrom-detect.templates
@@ -94,6 +94,19 @@ _Description: CD-ROM detected
  The CD-ROM autodetection was successful. A CD-ROM drive has been found and it
  currently contains the CD ${cdname}. The installation will now continue.
 
+Template: cdrom-detect/unetbootin_detected
+Type: note
+# :sl2:
+_Description: UNetbootin media detected
+ It appears that your installation disk was generated using
+ UNetbootin. UNetbootin is regularly linked with difficult or
+ unreproducible problem reports from Debian Installer users; if you
+ have problems using this installation disk, please try your
+ installation again without using UNetbootin before reporting issues.
+ .
+ The installation guide contains more information on how to create a
+ USB installation disk directly without UNetbootin.
+
 Template: cdrom-detect/wrong-cd
 Type: error
 # :sl2:
diff --git a/debian/changelog b/debian/changelog
index 22c2e1d..a4b037a 100644
--- a/debian/changelog
+++ b/debian/changelog
@@ -1,3 +1,11 @@
+cdrom-detect (1.49) UNRELEASED; urgency=medium
+
+  [ Steve McIntyre ]
+  * Add checks for UNetbootin media at cdrom mount time. If we detect it,
+    warn the user about potential problems. Closes: #744865
+
+ -- Steve McIntyre <93sam@debian.org>  Fri, 23 Jan 2015 01:03:28 +0100
+
 cdrom-detect (1.48) unstable; urgency=low
 
   [ Updated translations ]
